==> 1.0.1.tar.gz: lib/bloc_provider.dart <==
import 'package:flutter/material.dart';
import 'package:mwb/instantiable.dart';

/// Stateful widget that acts as the access to a specific BLoC.
///
/// Each BlocProvider instance is always bound to a specific BLoC type
/// and covers the corresponding scope within [child].
class BlocProvider<T extends BaseBloc> extends StatefulWidget {
  final T bloc;
  final Widget child;

  BlocProvider({Key key, @required this.bloc, @required this.child})
      : super(key: key);

  @override
  State createState() => _BlocProviderState();

  static T of<T extends BaseBloc>(BuildContext buildContext) {
    BlocProvider<T> provider = buildContext.findAncestorWidgetOfExactType();
    return provider.bloc;
  }
}

class _BlocProviderState extends State<BlocProvider> {
  @override
  void initState() {
    super.initState();
    widget.bloc.init();
  }

  @override
  Widget build(BuildContext context) {
    return widget.child;
  }

  @override
  void dispose() {
    widget.bloc.dispose();
    super.dispose();
  }
}

/// Base class for every BLoC that you want to create.
///
/// It acts as a business logic and data holder in order to separate logic & data from UI
/// In most cases a BLoC is responsible for a specific scope.
/// That scope is defined by the widget-subtree below the BlocProvider widget responsible
/// for the BLoC it contains.
///
/// For instance, you could set up an architecture with one BLoC per page and one for the entire app
/// similar to ehe MVP pattern on Android.
abstract class BaseBloc implements Instantiable {}

==> 2.0.0.tar.gz: lib/bloc_provider.dart <==
import 'package:flutter/material.dart';
import 'package:mwb/instantiable.dart';

/// Stateful widget that acts as the access to a specific BLoC.
///
/// Each BlocProvider instance is always bound to a specific BLoC type
/// and covers the corresponding scope within [child].
class BlocProvider<T extends BaseBloc> extends StatefulWidget {
  final T bloc;
  final Widget child;

  BlocProvider({Key? key, required this.bloc, required this.child})
      : super(key: key);

  @override
  State createState() => _BlocProviderState();

  static T? of<T extends BaseBloc>(BuildContext buildContext) {
    BlocProvider<T>? provider = buildContext.findAncestorWidgetOfExactType();
    return provider?.bloc;
  }
}

class _BlocProviderState extends State<BlocProvider> {
  @override
  void initState() {
    super.initState();
    widget.bloc.init();
  }

  @override
  Widget build(BuildContext context) {
    return widget.child;
  }

  @override
  void dispose() {
    widget.bloc.dispose();
    super.dispose();
  }
}

/// Base class for every BLoC that you want to create.
///
/// It acts as a business logic and data holder in order to separate logic & data from UI
/// In most cases a BLoC is responsible for a specific scope.
/// That scope is defined by the widget-subtree below the BlocProvider widget responsible
/// for the BLoC it contains.
///
/// For instance, you could set up an architecture with one BLoC per page and one for the entire app
/// similar to ehe MVP pattern on Android.
abstract class BaseBloc implements Instantiable {}
